@@ -5,7 +5,7 @@ from common_tools.log_tools.logger_main import GeneralLog
 from common_tools.datetime_tools.date_conversion import GeneralDatetime
 
 
-class Genaralcommon_tools(GeneralString, GeneralDatetime, GeneralLog):
+class Common_tools(GeneralString, GeneralDatetime, GeneralLog):
     def __init__(self, *args, **kwargs):
-        super(Genaralcommon_tools, self).__init__(*args, **kwargs)
-        self.logger.debug('Genaralcommon_tools initialized')
+        super(Common_tools, self).__init__(*args, **kwargs)
+        self.logger.debug('Common_tools initialized')
